@@ -20,16 +20,17 @@
 package org.joni;
 
 import org.joni.ast.CClassNode;
-import org.joni.ast.ConsAltNode;
+import org.joni.ast.ListNode;
 
-public final class ApplyCaseFoldArg {
+final class ApplyCaseFoldArg {
     final ScanEnvironment env;
-    final CClassNode cc;
-    ConsAltNode altRoot;
-    ConsAltNode tail;
+    final CClassNode cc, ascCc;
+    ListNode altRoot;
+    ListNode tail;
 
-    public ApplyCaseFoldArg(ScanEnvironment env, CClassNode cc) {
+    ApplyCaseFoldArg(ScanEnvironment env, CClassNode cc, CClassNode ascCc) {
         this.env = env;
         this.cc = cc;
+        this.ascCc = ascCc;
     }
 }
