@@ -19,8 +19,7 @@
  */
 package org.joni;
 
-public class Option {
-
+public final class Option {
     /* options */
     public static final int NONE                 = 0;
     public static final int IGNORECASE           = (1 << 0);
@@ -46,27 +45,27 @@ public class Option {
     public static final int NEWLINE_CRLF         = (1 << 15);
     public static final int NOTBOS               = (1 << 16);
     public static final int NOTEOS               = (1 << 17);
+    public static final int CR_7_BIT             = (1 << 18);
 
-    public static final int MAXBIT               = (1 << 18); /* limit */
+    public static final int MAXBIT               = (1 << 19); /* limit */
 
     public static final int DEFAULT              = NONE;
 
     public static String toString(int option) {
         String options = "";
-        if (isIgnoreCase(option)) options += "IGNORECASE ";
-        if (isExtend(option)) options += "EXTEND ";
-        if (isMultiline(option)) options += "MULTILINE ";
-        if (isSingleline(option)) options += "SINGLELINE ";
-        if (isFindLongest(option)) options += "FIND_LONGEST ";
-        if (isFindNotEmpty(option)) options += "FIND_NOT_EMPTY  ";
-        if (isNegateSingleline(option)) options += "NEGATE_SINGLELINE ";
-        if (isDontCaptureGroup(option)) options += "DONT_CAPTURE_GROUP ";
-        if (isCaptureGroup(option)) options += "CAPTURE_GROUP ";
-
-        if (isNotBol(option)) options += "NOTBOL ";
-        if (isNotEol(option)) options += "NOTEOL ";
-        if (isPosixRegion(option)) options += "POSIX_REGION ";
-
+        if (isIgnoreCase(option)) options += "IGNORECASE";
+        if (isExtend(option)) options += "EXTEND";
+        if (isMultiline(option)) options += "MULTILINE";
+        if (isSingleline(option)) options += "SINGLELINE";
+        if (isFindLongest(option)) options += "FIND_LONGEST";
+        if (isFindNotEmpty(option)) options += "FIND_NOT_EMPTY";
+        if (isNegateSingleline(option)) options += "NEGATE_SINGLELINE";
+        if (isDontCaptureGroup(option)) options += "DONT_CAPTURE_GROUP";
+        if (isCaptureGroup(option)) options += "CAPTURE_GROUP";
+        if (isNotBol(option)) options += "NOTBOL";
+        if (isNotEol(option)) options += "NOTEOL";
+        if (isPosixRegion(option)) options += "POSIX_REGION";
+        if (isCR7Bit(option)) options += "CR_7_BIT";
         return options;
     }
 
@@ -126,11 +125,25 @@ public class Option {
         return (option & ASCII_RANGE) != 0;
     }
 
-    /* OP_SET_OPTION is required for these options.  ??? */
-    //    public static boolean isDynamic(int option) {
-    //        return (option & (MULTILINE | IGNORECASE)) != 0;
-    //    }
+    public static boolean isPosixBracketAllRange(int option) {
+        return (option & POSIX_BRACKET_ALL_RANGE) != 0;
+    }
+
+    public static boolean isWordBoundAllRange(int option) {
+        return (option & WORD_BOUND_ALL_RANGE) != 0;
+    }
+
+    public static boolean isNewlineCRLF(int option) {
+        return (option & NEWLINE_CRLF) != 0;
+    }
+
+    public static boolean isCR7Bit(int option) {
+        return (option & CR_7_BIT) != 0;
+    }
+
     public static boolean isDynamic(int option) {
+        // ignore-case and multibyte status are included in compiled code
+        // return (option & (MULTILINE | IGNORECASE)) != 0;
         return false;
     }
 }
