@@ -29,14 +29,13 @@ import org.joni.exception.InternalException;
 public final class ScanEnvironment {
     public int option;
     final int caseFoldFlag;
-    final public Encoding enc;
-    final public Syntax syntax;
+    public final Encoding enc;
+    public final Syntax syntax;
     int captureHistory;
     int btMemStart;
     int btMemEnd;
     int backrefedMem;
 
-    final public Regex reg;
     public final WarnCallback warnings;
 
     int numCall;
@@ -57,16 +56,15 @@ public final class ScanEnvironment {
     int numPrecReadNotNodes;
     Node precReadNotNodes[];
 
-    public ScanEnvironment(Regex regex, Syntax syntax, WarnCallback warnings) {
-        this.reg = regex;
+    ScanEnvironment(Regex regex, Syntax syntax, WarnCallback warnings) {
         this.syntax = syntax;
         this.warnings = warnings;
-        option = reg.options;
-        caseFoldFlag = reg.caseFoldFlag;
-        enc = reg.enc;
+        option = regex.options;
+        caseFoldFlag = regex.caseFoldFlag;
+        enc = regex.enc;
     }
 
-    public int addMemEntry() {
+    int addMemEntry() {
         if (numMem >= Config.MAX_CAPTURE_GROUP_NUM) throw new InternalException(ErrorMessages.TOO_MANY_CAPTURE_GROUPS);
         if (numMem++ == 0) {
             memNodes = new EncloseNode[Config.SCANENV_MEMNODES_SIZE];
@@ -79,7 +77,7 @@ public final class ScanEnvironment {
         return numMem;
     }
 
-    public void setMemNode(int num, EncloseNode node) {
+    void setMemNode(int num, EncloseNode node) {
         if (numMem >= num) {
             memNodes[num] = node;
         } else {
@@ -87,7 +85,8 @@ public final class ScanEnvironment {
         }
     }
 
-    public void pushPrecReadNotNode(Node node) {
+
+    void pushPrecReadNotNode(Node node) {
         numPrecReadNotNodes++;
         if (precReadNotNodes == null) {
             precReadNotNodes = new Node[Config.SCANENV_MEMNODES_SIZE];
@@ -99,21 +98,21 @@ public final class ScanEnvironment {
         precReadNotNodes[numPrecReadNotNodes - 1] = node;
     }
 
-    public void popPrecReadNotNode(Node node) {
+    void popPrecReadNotNode(Node node) {
         if (precReadNotNodes != null && precReadNotNodes[numPrecReadNotNodes - 1] == node) {
             precReadNotNodes[numPrecReadNotNodes - 1] = null;
             numPrecReadNotNodes--;
         }
     }
 
-    public Node currentPrecReadNotNode() {
+    Node currentPrecReadNotNode() {
         if (numPrecReadNotNodes > 0) {
             return precReadNotNodes[numPrecReadNotNodes - 1];
         }
         return null;
     }
 
-    public int convertBackslashValue(int c) {
+    int convertBackslashValue(int c) {
         if (syntax.opEscControlChars()) {
             switch (c) {
             case 'n': return '\n';
@@ -127,22 +126,28 @@ public final class ScanEnvironment {
                 if (syntax.op2EscVVtab()) return 11; // '\v'
                 break;
             default:
-                if (('a' <= c && c <= 'z') || ('A' <= c && c <= 'Z')) ccEscWarn(String.valueOf((char)c));
+                if (('a' <= c && c <= 'z') || ('A' <= c && c <= 'Z')) unknownEscWarn(String.valueOf((char)c));
             }
         }
         return c;
     }
 
     void ccEscWarn(String s) {
-        if (Config.USE_WARN) {
+        if (warnings != WarnCallback.NONE) {
             if (syntax.warnCCOpNotEscaped() && syntax.backSlashEscapeInCC()) {
                 warnings.warn("character class has '" + s + "' without escape");
             }
         }
     }
 
+    void unknownEscWarn(String s) {
+        if (warnings != WarnCallback.NONE) {
+            warnings.warn("Unknown escape \\" + s + " is ignored");
+        }
+    }
+
     void closeBracketWithoutEscapeWarn(String s) {
-        if (Config.USE_WARN) {
+        if (warnings != WarnCallback.NONE) {
             if (syntax.warnCCOpNotEscaped()) {
                 warnings.warn("regular expression has '" + s + "' without escape");
             }
