@@ -320,6 +320,7 @@ public class TestU8 extends Test {
         x2s("(?~abc|def)x", "abcx", 1, 4);
         x2s("(?~abc|def)x", "defx", 1, 4);
         x2s("^(?~\\S+)TEST", "TEST", 0, 4);
+        x3s("(?~(a)c)", "aab", -1, -1, 1); //    # $1 should not match.
 
         x2s("𠜎𠜱", "𠜎𠜱", 0, 8);
         x2s("𠜎?𠜱", "𠜎𠜱", 0, 8);
@@ -348,5 +349,11 @@ public class TestU8 extends Test {
         ns("^.+$", "\n");
 
         ns("💌", "aa");
+        ns("aa", "💌");
+
+        x2s("\\P{In_Supplemental_Symbols_and_Pictographs}?", "", 0, 0);
+        x2s("\\P{In_Transport_and_Map_Symbols}?", "", 0, 0);
+
+        x2s("^(\"|)(.*)\\1$", "X6", 0, 2);
     }
 }
